@@ -2,6 +2,7 @@
 # -*- coding: utf-8 -*-
 
 import re
+from pyutilb.util import *
 from lxml import etree
 from requests import Response
 from jsonpath import jsonpath
@@ -16,25 +17,17 @@ class ResponseWrap(object):
     # 获得元素值
     def _get_val_by(self, type, path):
         if type == 'css':
+            path, prop = split_xpath_and_prop(path)
             # html = etree.parse(self.res.text, etree.HTMLParser()) # parse的是html文件
             html = etree.fromstring(self.res.text, etree.HTMLParser()) # fromstring的是html文本
-            return html.cssselect(path)[0].text
+            ele = html.cssselect(path)[0]
+            return self.get_prop_or_text(ele, prop)
 
         if type == 'xpath':
-            # 检查xpath是否最后有属性
-            mat = re.search('/@[\w\d_]+$', path)
-            prop = ''
-            if (mat != None):  # 有属性
-                # 分离元素path+属性
-                prop = mat.group()
-                path = path.replace(prop, '')
-                prop = prop.replace('/@', '')
-
+            path, prop = split_xpath_and_prop(path)
             html = etree.fromstring(self.res.text, etree.HTMLParser())
             ele = html.xpath(path)[0]
-            if prop != '': # 获得属性
-                return ele.get(prop)
-            return ele.text
+            return self.get_prop_or_text(ele, prop)
 
         if type == 'jsonpath':
             data = self.res.json()
@@ -44,4 +37,18 @@ class ResponseWrap(object):
             html = etree.parse(self.res.text, etree.HTMLParser())
             return html.get_element_by_id(path).text
 
-        raise Exception(f"不支持查找类型: {type}")
\ No newline at end of file
+        if type == 'eval':
+            return eval(path, globals(), bvars) # 丢失本地与全局变量, 如引用不了json模块
+
+        raise Exception(f"Invalid find type: {type}")
+
+
+    # 获得元素的属性值或文本
+    def get_prop_or_text(self, ele, prop):
+        # 响应元素
+        if isinstance(ele, etree._Element):
+            if prop != '':  # 获得属性
+                return ele.get(prop)
+            return ele.text
+
+        raise Exception('Invalid element')
